pub enum ExchangeEvents {
LiquidationStarted(LiquidationStarted),
LiquidationResolved(LiquidationResolved),
LiquidationStopped(LiquidationStopped),
AuctioneerSet(AuctioneerSet),
}Expand description
Container for all the Exchange events.
Variants
LiquidationStarted(LiquidationStarted)
LiquidationResolved(LiquidationResolved)
LiquidationStopped(LiquidationStopped)
AuctioneerSet(AuctioneerSet)
Implementations
Sourceimpl ExchangeEvents
impl ExchangeEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ExchangeEvents
impl ExchangeEvents
Sourcepub fn liquidation_started(
account: Address,
equity: I256,
margin_needed: U256,
) -> Self
pub fn liquidation_started( account: Address, equity: I256, margin_needed: U256, ) -> Self
Creates a LiquidationStarted event.
event LiquidationStarted(address,int256,uint256)Sourcepub fn liquidation_resolved(
account: Address,
winner: Address,
bonus: U256,
) -> Self
pub fn liquidation_resolved( account: Address, winner: Address, bonus: U256, ) -> Self
Creates a LiquidationResolved event.
event LiquidationResolved(address,address,uint256)Sourcepub fn liquidation_stopped(account: Address) -> Self
pub fn liquidation_stopped(account: Address) -> Self
Creates a LiquidationStopped event.
event LiquidationStopped(address)Sourcepub fn auctioneer_set(auctioneer: Address) -> Self
pub fn auctioneer_set(auctioneer: Address) -> Self
Creates a AuctioneerSet event.
event AuctioneerSet(address)Trait Implementations
Sourceimpl Clone for ExchangeEvents
impl Clone for ExchangeEvents
Sourcefn clone(&self) -> ExchangeEvents
fn clone(&self) -> ExchangeEvents
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for ExchangeEvents
impl IntoLogData for ExchangeEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a [
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a [
LogData] object.Sourceimpl SolEventInterface for ExchangeEvents
impl SolEventInterface for ExchangeEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
Decode the events from the given log info.
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
Decode the events from the given log object.